from decouple import config
from sendgrid import SendGridAPIClient
from sendgrid.helpers.mail import Mail


def send_mail(sender,receiver,subject,html, api_key):
    """
    Use this function to set up the `email sender`, `the recipient`, `email subject`,  the `html content` of the email and the `api_key` from Sendgrid..

    """
    message = Mail(
        from_email=sender,
        to_emails=receiver,
        subject=subject,
        html_content=html
        )

    try:
        API_KEY = api_key
        sg = SendGridAPIClient(API_KEY)
        response = sg.send(message)
        print('Email sent successfully.')
    except Exception as e:
        print(f'Error while sending email. {e}')    


from setuptools import setup, find_packages

with open("README.md","r") as infile:
    README = infile.read()

# This call to setup() does all the work
setup(
    name="dsc-mailer",
    version="1.0.0",
    description="A simple mailing library for python powered applications using Sendgrid.",
    packages=find_packages(),
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/jkuatdsc/dsc-mailer",
    download_url='https://github.com/jkuatdsc/dsc-mailer.git',
    author="Victor Waichigo",
    author_email="waichigovick@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    include_package_data=True,
    install_requires=["sendgrid", "python-decouple"],
)
